@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011-2017 Montel Laurent <montel@kde.org>
+ * Copyright (c) 2011-2018 Montel Laurent <montel@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -111,8 +111,8 @@ void SpellCheckLineEdit::insertFromMimeData(const QMimeData *source)
         // replace \r with \n to make xterm pastes happy
         pasteText.replace(QLatin1Char('\r'), QLatin1Char('\n'));
         // remove blank lines
-        while (pasteText.contains(QStringLiteral("\n\n"))) {
-            pasteText.replace(QStringLiteral("\n\n"), QStringLiteral("\n"));
+        while (pasteText.contains(QLatin1String("\n\n"))) {
+            pasteText.replace(QLatin1String("\n\n"), QLatin1String("\n"));
         }
 
         QRegExp reTopSpace(QStringLiteral("^ *\n"));
